@@ -268,8 +268,8 @@ int readGisHeader( const char* name,_image* im)
 
   status = (int)iss.str().length();
   switch ( status ) {
-  case 2 :    im->zdim = 1;
-  case 3 :    im->vdim = 1;
+  case 2 :    im->zdim = 1; CGAL_FALLTHROUGH;
+  case 3 :    im->vdim = 1; CGAL_FALLTHROUGH;
   case 4 :    break;
   default :
     fprintf( stderr, "readGisHeader: unable to read dimensions in '%s'\n", name );
