@@ -21,7 +21,9 @@
 #ifndef CGAL_POLYGON_MESH_PROCESSING_TRIANGULATE_FACES_H
 #define CGAL_POLYGON_MESH_PROCESSING_TRIANGULATE_FACES_H
 
-#include <CGAL/HalfedgeDS_decorator.h>
+#include <CGAL/license/Polygon_mesh_processing/meshing_hole_filling.h>
+
+
 #include <CGAL/boost/graph/helpers.h>
 #include <CGAL/boost/graph/Euler_operations.h>
 
@@ -104,13 +106,13 @@ public:
     {
       halfedge_descriptor v0, v1, v2, v3;
       v0 = halfedge(f, pmesh);
-      Point_ref p0 = _vpmap[target(v0, pmesh)];
+      Point_ref p0 = get(_vpmap, target(v0, pmesh));
       v1 = next(v0, pmesh);
-      Point_ref p1 = _vpmap[target(v1, pmesh)];
+      Point_ref p1 = get(_vpmap, target(v1, pmesh));
       v2 = next(v1, pmesh);
-      Point_ref p2 = _vpmap[target(v2, pmesh)];
+      Point_ref p2 = get(_vpmap, target(v2, pmesh));
       v3 = next(v2, pmesh);
-      Point_ref p3 = _vpmap[target(v3, pmesh)];
+      Point_ref p3 = get(_vpmap, target(v3, pmesh));
 
       /* Chooses the diagonal that will split the quad in two triangles that maximize
        * the scalar product of of the un-normalized normals of the two triangles.
@@ -144,7 +146,7 @@ public:
       Tr_Vertex_handle previous, first;
       do
       {
-        Tr_Vertex_handle vh = cdt.insert(_vpmap[target(h, pmesh)]);
+        Tr_Vertex_handle vh = cdt.insert(get(_vpmap, target(h, pmesh)));
         if (first == Tr_Vertex_handle()) {
           first = vh;
         }
@@ -304,7 +306,6 @@ public:
 * \ingroup PMP_meshing_grp
 * triangulates a single face of a polygon mesh. This function depends on the package \ref PkgTriangulation2Summary
 * @tparam PolygonMesh a model of `FaceListGraph` and `MutableFaceGraph`
-*         that has an internal property map for `boost::vertex_point_t`
 * @tparam NamedParameters a sequence of \ref namedparameters
 *
 * @param f face to be triangulated
@@ -313,7 +314,9 @@ public:
 *
 *
 * \cgalNamedParamsBegin
-*    \cgalParamBegin{vertex_point_map} the property map with the points associated to the vertices of `pmesh` \cgalParamEnd
+*    \cgalParamBegin{vertex_point_map} the property map with the points associated to the vertices of `pmesh`.
+*   If this parameter is omitted, an internal property map for
+*   `CGAL::vertex_point_t` should be available in `PolygonMesh`\cgalParamEnd
 *    \cgalParamBegin{geom_traits} a geometric traits class instance \cgalParamEnd
 * \cgalNamedParamsEnd
 *
@@ -324,14 +327,13 @@ bool  triangulate_face(typename boost::graph_traits<PolygonMesh>::face_descripto
                       PolygonMesh& pmesh,
                       const NamedParameters& np)
 {
-  using boost::choose_const_pmap;
+  using boost::choose_param;
   using boost::get_param;
 
   //VertexPointMap
   typedef typename GetVertexPointMap<PolygonMesh, NamedParameters>::type VPMap;
-  VPMap vpmap = choose_pmap(get_param(np, boost::vertex_point),
-                            pmesh,
-                            boost::vertex_point);
+  VPMap vpmap = choose_param(get_param(np, vertex_point),
+                             get_property_map(vertex_point, pmesh));
   //Kernel
   typedef typename GetGeomTraits<PolygonMesh, NamedParameters>::type Kernel;
 
@@ -354,7 +356,6 @@ bool triangulate_face(typename boost::graph_traits<PolygonMesh>::face_descriptor
           model of `Range`.
           Its iterator type is `InputIterator`.
 * @tparam PolygonMesh a model of `FaceListGraph` and `MutableFaceGraph`
-*         that has an internal property map for `boost::vertex_point_t`
 * @tparam NamedParameters a sequence of \ref namedparameters
 *
 * @param face_range the range of faces to be triangulated
@@ -362,7 +363,9 @@ bool triangulate_face(typename boost::graph_traits<PolygonMesh>::face_descriptor
 * @param np optional sequence of \ref namedparameters among the ones listed below
 *
 * \cgalNamedParamsBegin
-*    \cgalParamBegin{vertex_point_map} the property map with the points associated to the vertices of `pmesh` \cgalParamEnd
+*    \cgalParamBegin{vertex_point_map} the property map with the points associated to the vertices of `pmesh`.
+*   If this parameter is omitted, an internal property map for
+*   `CGAL::vertex_point_t` should be available in `PolygonMesh`\cgalParamEnd
 *    \cgalParamBegin{geom_traits} a geometric traits class instance \cgalParamEnd
 * \cgalNamedParamsEnd
 *
@@ -374,14 +377,13 @@ bool triangulate_faces(FaceRange face_range,
                        PolygonMesh& pmesh,
                        const NamedParameters& np)
 {
-  using boost::choose_const_pmap;
+  using boost::choose_param;
   using boost::get_param;
 
   //VertexPointMap
   typedef typename GetVertexPointMap<PolygonMesh, NamedParameters>::type VPMap;
-  VPMap vpmap = choose_pmap(get_param(np, boost::vertex_point),
-                            pmesh,
-                            boost::vertex_point);
+  VPMap vpmap = choose_param(get_param(np, vertex_point),
+                             get_property_map(vertex_point, pmesh));
   //Kernel
   typedef typename GetGeomTraits<PolygonMesh, NamedParameters>::type Kernel;
 
@@ -399,14 +401,15 @@ bool triangulate_faces(FaceRange face_range, PolygonMesh& pmesh)
 * \ingroup PMP_meshing_grp
 * triangulates all faces of a polygon mesh. This function depends on the package \ref PkgTriangulation2Summary
 * @tparam PolygonMesh a model of `FaceListGraph` and `MutableFaceGraph`
-*         that has an internal property map for `boost::vertex_point_t`
 * @tparam NamedParameters a sequence of \ref namedparameters
 *
 * @param pmesh the polygon mesh to be triangulated
 * @param np optional sequence of \ref namedparameters among the ones listed below
 *
 * \cgalNamedParamsBegin
-*    \cgalParamBegin{vertex_point_map} the property map with the points associated to the vertices of `pmesh` \cgalParamEnd
+*    \cgalParamBegin{vertex_point_map} the property map with the points associated to the vertices of `pmesh`.
+*   If this parameter is omitted, an internal property map for
+*   `CGAL::vertex_point_t` should be available in `PolygonMesh`\cgalParamEnd
 *    \cgalParamBegin{geom_traits} a geometric traits class instance \cgalParamEnd
 * \cgalNamedParamsEnd
 *
